@@ -1,12 +1,15 @@
+from .core.isql_config import init_isql
 from .core.isql import iSQL, iSqlDF
 
 from .utils.paths import (
     base_dir, tests_dir, package_dir,
-    assets_dir, config
+    assets_dir
 )
 
 from .utils.render import console, errors
 
-from .cli.query import qapp
+from .utils.local_store import iSqlConfig
+
 from .cli.run import run
-from .cli.execute import exe
\ No newline at end of file
+from .cli.execute import exe
+from .cli.config import config, isqlcfg
\ No newline at end of file
