@@ -4,10 +4,13 @@ import typer
 from pathlib import Path
 from typing import List, Tuple, Dict, Union, Optional, Any, Iterator, TypeVar
 from pisql.core.isql import iSQL
+from pisql.core.isql_config import init_isql
 from pisql.utils.paths import (
     base_dir, tests_dir, package_dir
 )
 
+isql = init_isql()
+
 exe = typer.Typer(
     name="execute",
     help=f"""Execute a query against a Sybase ASE database . Accepts a .sql file ",
