@@ -5,13 +5,17 @@ from pathlib import Path
 from typing import List, Tuple, Dict, Union, Optional, Any, Iterator, TypeVar
 
 from iotree.core.render.funcs import basic_pbar, rich_func_chainer
+
+from pisql.utils.config import config, isqlcfg
 from pisql.core.isql import iSQL
+from pisql.core.isql_config import init_isql
 from pisql.utils.render import console, errors
+
 from pisql.utils.paths import (
-    base_dir, tests_dir, package_dir, config, assets_dir, data_dir, pisql_home
+    base_dir, tests_dir, package_dir, assets_dir, data_dir, pisql_home
 )
 
-isql = iSQL(**config["default"])
+isql = init_isql()
 
 run = typer.Typer(
     name="run",
@@ -62,7 +66,7 @@ def runallAlias(
 def listTablesServer() -> None:
     """List all tables  in the server """
     querytxt = """
-    SELECT t.name, c.name
+    SELECT t.name as table_name, c.name as column_name
     FROM sysobjects t, syscolumns c
     WHERE t.id = c.id AND t.type IN ('U', 'V')
     """
