@@ -127,7 +127,7 @@ class iSQL:
         self,
         filename: Union[str, os.PathLike, Path],
         preprocess: Optional[bool] = True,
-        ) -> pl.DataFrame:
+        ) -> iSqlDF:
         """Run a query and return the result as a list of tuples."""
         
         self.preprocess = preprocess
@@ -190,7 +190,7 @@ class iSQL:
         
         try:
             return self.run_sql_file(
-                file = filename,
+                filename,
                 preprocess = preprocess
             )
         except Exception as err:
@@ -248,7 +248,7 @@ class iSQL:
         return df
 
     def multiquery(self, queries_source: Union[str, os.PathLike, Path]) -> List[iSqlDF]:
-        """Run multiple queries and return the result as a list of pl.DataFrames"""
+        """Run multiple queries and return the result as a list of iSqlDFs"""
         if isinstance(queries_source, (Path, os.PathLike, str, list)):
             if not isinstance(queries_source, list):
                 if Path(queries_source).is_dir():
@@ -291,11 +291,11 @@ class iSQL:
     def __lt__(self, other):
         return self.copy().query(other)
 
-    def __rshift__(self, queries_source: Union[str, os.PathLike, Path]) -> List[pl.DataFrame]:
+    def __rshift__(self, queries_source: Union[str, os.PathLike, Path]) -> List[iSqlDF]:
         """Pipes a list of .sql files or a directory name to the pisql 🐍 command 🦾"""
         return self.multiquery(queries_source)
 
-    def __rshift__(self, queries_source: Union[str, os.PathLike, Path]) -> List[pl.DataFrame]:
+    def __rshift__(self, queries_source: Union[str, os.PathLike, Path]) -> List[iSqlDF]:
         """Pipes a list of .sql files or a directory name to the pisql 🐍 command 🦾"""
         return self.multiquery(queries_source)
         
\ No newline at end of file
